@@ -29,6 +29,13 @@ __all__ = (
     "AdvancedOptionsStatusTypeDef",
     "AdvancedSecurityOptionsStatusTypeDef",
     "AdvancedSecurityOptionsTypeDef",
+    "AutoTuneDetailsTypeDef",
+    "AutoTuneMaintenanceScheduleTypeDef",
+    "AutoTuneOptionsOutputTypeDef",
+    "AutoTuneOptionsStatusTypeDef",
+    "AutoTuneOptionsTypeDef",
+    "AutoTuneStatusTypeDef",
+    "AutoTuneTypeDef",
     "CognitoOptionsStatusTypeDef",
     "CognitoOptionsTypeDef",
     "CompatibleVersionsMapTypeDef",
@@ -37,6 +44,7 @@ __all__ = (
     "DomainInfoTypeDef",
     "DomainInformationTypeDef",
     "DomainPackageDetailsTypeDef",
+    "DurationTypeDef",
     "EBSOptionsStatusTypeDef",
     "EBSOptionsTypeDef",
     "ElasticsearchClusterConfigStatusTypeDef",
@@ -69,6 +77,7 @@ __all__ = (
     "SAMLIdpTypeDef",
     "SAMLOptionsInputTypeDef",
     "SAMLOptionsOutputTypeDef",
+    "ScheduledAutoTuneDetailsTypeDef",
     "ServiceSoftwareOptionsTypeDef",
     "SnapshotOptionsStatusTypeDef",
     "SnapshotOptionsTypeDef",
@@ -83,6 +92,7 @@ __all__ = (
     "AcceptInboundCrossClusterSearchConnectionResponseTypeDef",
     "AdvancedSecurityOptionsInputTypeDef",
     "AssociatePackageResponseTypeDef",
+    "AutoTuneOptionsInputTypeDef",
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "CreateElasticsearchDomainResponseTypeDef",
     "CreateOutboundCrossClusterSearchConnectionResponseTypeDef",
@@ -91,6 +101,7 @@ __all__ = (
     "DeleteInboundCrossClusterSearchConnectionResponseTypeDef",
     "DeleteOutboundCrossClusterSearchConnectionResponseTypeDef",
     "DeletePackageResponseTypeDef",
+    "DescribeDomainAutoTunesResponseTypeDef",
     "DescribeElasticsearchDomainConfigResponseTypeDef",
     "DescribeElasticsearchDomainResponseTypeDef",
     "DescribeElasticsearchDomainsResponseTypeDef",
@@ -151,6 +162,89 @@ AdvancedSecurityOptionsTypeDef = TypedDict(
     total=False,
 )
 
+AutoTuneDetailsTypeDef = TypedDict(
+    "AutoTuneDetailsTypeDef",
+    {"ScheduledAutoTuneDetails": "ScheduledAutoTuneDetailsTypeDef"},
+    total=False,
+)
+
+AutoTuneMaintenanceScheduleTypeDef = TypedDict(
+    "AutoTuneMaintenanceScheduleTypeDef",
+    {"StartAt": datetime, "Duration": "DurationTypeDef", "CronExpressionForRecurrence": str},
+    total=False,
+)
+
+AutoTuneOptionsOutputTypeDef = TypedDict(
+    "AutoTuneOptionsOutputTypeDef",
+    {
+        "State": Literal[
+            "ENABLED",
+            "DISABLED",
+            "ENABLE_IN_PROGRESS",
+            "DISABLE_IN_PROGRESS",
+            "DISABLED_AND_ROLLBACK_SCHEDULED",
+            "DISABLED_AND_ROLLBACK_IN_PROGRESS",
+            "DISABLED_AND_ROLLBACK_COMPLETE",
+            "DISABLED_AND_ROLLBACK_ERROR",
+            "ERROR",
+        ],
+        "ErrorMessage": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+AutoTuneOptionsStatusTypeDef = TypedDict(
+    "AutoTuneOptionsStatusTypeDef",
+    {"Options": "AutoTuneOptionsTypeDef", "Status": "AutoTuneStatusTypeDef"},
+    total=False,
+)
+
+AutoTuneOptionsTypeDef = TypedDict(
+    "AutoTuneOptionsTypeDef",
+    {
+        "DesiredState": Literal["ENABLED", "DISABLED"],
+        "RollbackOnDisable": Literal["NO_ROLLBACK", "DEFAULT_ROLLBACK"],
+        "MaintenanceSchedules": List["AutoTuneMaintenanceScheduleTypeDef"],
+    },
+    total=False,
+)
+
+_RequiredAutoTuneStatusTypeDef = TypedDict(
+    "_RequiredAutoTuneStatusTypeDef",
+    {
+        "CreationDate": datetime,
+        "UpdateDate": datetime,
+        "State": Literal[
+            "ENABLED",
+            "DISABLED",
+            "ENABLE_IN_PROGRESS",
+            "DISABLE_IN_PROGRESS",
+            "DISABLED_AND_ROLLBACK_SCHEDULED",
+            "DISABLED_AND_ROLLBACK_IN_PROGRESS",
+            "DISABLED_AND_ROLLBACK_COMPLETE",
+            "DISABLED_AND_ROLLBACK_ERROR",
+            "ERROR",
+        ],
+    },
+)
+_OptionalAutoTuneStatusTypeDef = TypedDict(
+    "_OptionalAutoTuneStatusTypeDef",
+    {"UpdateVersion": int, "ErrorMessage": str, "PendingDeletion": bool},
+    total=False,
+)
+
+
+class AutoTuneStatusTypeDef(_RequiredAutoTuneStatusTypeDef, _OptionalAutoTuneStatusTypeDef):
+    pass
+
+
+AutoTuneTypeDef = TypedDict(
+    "AutoTuneTypeDef",
+    {"AutoTuneType": Literal["SCHEDULED_ACTION"], "AutoTuneDetails": "AutoTuneDetailsTypeDef"},
+    total=False,
+)
+
 CognitoOptionsStatusTypeDef = TypedDict(
     "CognitoOptionsStatusTypeDef",
     {"Options": "CognitoOptionsTypeDef", "Status": "OptionStatusTypeDef"},
@@ -217,6 +311,10 @@ DomainPackageDetailsTypeDef = TypedDict(
     total=False,
 )
 
+DurationTypeDef = TypedDict(
+    "DurationTypeDef", {"Value": int, "Unit": Literal["HOURS"]}, total=False
+)
+
 EBSOptionsStatusTypeDef = TypedDict(
     "EBSOptionsStatusTypeDef", {"Options": "EBSOptionsTypeDef", "Status": "OptionStatusTypeDef"}
 )
@@ -388,6 +486,7 @@ ElasticsearchDomainConfigTypeDef = TypedDict(
         "LogPublishingOptions": "LogPublishingOptionsStatusTypeDef",
         "DomainEndpointOptions": "DomainEndpointOptionsStatusTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsStatusTypeDef",
+        "AutoTuneOptions": "AutoTuneOptionsStatusTypeDef",
     },
     total=False,
 )
@@ -426,6 +525,7 @@ _OptionalElasticsearchDomainStatusTypeDef = TypedDict(
         "ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef",
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsTypeDef",
+        "AutoTuneOptions": "AutoTuneOptionsOutputTypeDef",
     },
     total=False,
 )
@@ -804,6 +904,17 @@ SAMLOptionsOutputTypeDef = TypedDict(
     total=False,
 )
 
+ScheduledAutoTuneDetailsTypeDef = TypedDict(
+    "ScheduledAutoTuneDetailsTypeDef",
+    {
+        "Date": datetime,
+        "ActionType": Literal["JVM_HEAP_SIZE_TUNING", "JVM_YOUNG_GEN_TUNING"],
+        "Action": str,
+        "Severity": Literal["LOW", "MEDIUM", "HIGH"],
+    },
+    total=False,
+)
+
 ServiceSoftwareOptionsTypeDef = TypedDict(
     "ServiceSoftwareOptionsTypeDef",
     {
@@ -911,6 +1022,15 @@ AssociatePackageResponseTypeDef = TypedDict(
     total=False,
 )
 
+AutoTuneOptionsInputTypeDef = TypedDict(
+    "AutoTuneOptionsInputTypeDef",
+    {
+        "DesiredState": Literal["ENABLED", "DISABLED"],
+        "MaintenanceSchedules": List["AutoTuneMaintenanceScheduleTypeDef"],
+    },
+    total=False,
+)
+
 CancelElasticsearchServiceSoftwareUpdateResponseTypeDef = TypedDict(
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
     {"ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef"},
@@ -961,6 +1081,12 @@ DeletePackageResponseTypeDef = TypedDict(
     "DeletePackageResponseTypeDef", {"PackageDetails": "PackageDetailsTypeDef"}, total=False
 )
 
+DescribeDomainAutoTunesResponseTypeDef = TypedDict(
+    "DescribeDomainAutoTunesResponseTypeDef",
+    {"AutoTunes": List["AutoTuneTypeDef"], "NextToken": str},
+    total=False,
+)
+
 DescribeElasticsearchDomainConfigResponseTypeDef = TypedDict(
     "DescribeElasticsearchDomainConfigResponseTypeDef",
     {"DomainConfig": "ElasticsearchDomainConfigTypeDef"},
